#ifndef WHSH
#define WHSH

/******************************************************************************
               WHS Constants
*******************************************************************************/
#if defined (_WIN32)
   #if !defined(WIN32)
     #define WIN32
   #endif
#endif

// flags
#define WHFLAG_RETURN_MSG_ID 0x1
#define WHFLAG_SEGMENT_ONLY  0x2
#define WHFLAG_EMBED_PICTURE 0x4
#define WHFLAG_NO_PICT_PATH  0x8
#define WHFLAG_LIST_TO_TEXT  0x10
#define WHFLAG_NO_LINK_IN_DOC 0x20     // ignore links when converting from html to rtf
#define WHFLAG_WORDPAD_COMPATIBLE_PICT 0x40     // create WordPad compatible pictures in the rtf output
#define WHFLAG_NO_SPAN_TAG    0x80     // do not write the span tags
#define WHFLAG_NO_FONT        0x100    // do not write the font tag
#define WHFLAG_FLASH_SUPPORT  0x200    // html output for flash support
#define WHFLAG_XLATE_SINGLE_QUOTE 0x400  // translate single quote to &#39;
#define WHFLAG_SAVE_PICT_AS_BMP   0x800  // save picture as bmp in html output
#define WHFLAG_PNG_RGB           0x1000  // save png in rgb (high quality)
#define WHFLAG_FIX_NEG_INDENT    0x2000  // fix negative indent during docx read
#define WHFLAG_NO_COMBOBOX       0x4000  // convert combobox to plain text
#define WHFLAG_INPUT_FIELD_TO_TEXT_BOX 0x8000 // convert the input fields to text-box when wrinting html
#define WHFLAG_EMBED_HTML_PICTURE 0x10000  // embed pictures into html

#define HF_FIRST_HDR         0
#define HF_FIRST_FTR         1
#define HF_HDR               2
#define HF_FTR               3

#define HFTYPE_TEXT          0
#define HFTYPE_DOC           1
#define HFTYPE_HTML          2

// Error messages
#define MSG_FILE_NOT_FOUND     1
#define MSG_NO_EDITOR_INSTANCE 2
#define MSG_READ_ERROR         3
#define MSG_WRITE_ERROR        4
#define MSG_MEMORY_LOCK        5
#define MSG_NO_FILE_SIGNATURE  6
#define MSG_BAD_DOC_FILE       7
#define MSG_BAD_HTML_FILE      8
#define MSG_EXPIRED            9
#define MSG_TXML_NOT_LOADED   10
#define MSG_DOC_TO_RTF        11
#define MSG_LICENSE_EXCEEDED   15
#define MSG_BAD_LICENSE_NUMBER 16
#define MSG_BAD_LICENSE_KEY    17
#define MSG_INVALID_SERVER_LICENSE 18
#define MSG_LICENSE_EXPIRED        19

#define MSG_OTHER             99

/******************************************************************************
    WIN32 specific defines
*******************************************************************************/
#if defined (WIN32)
   #define WHS_HUGE
   #define _export
#else
   #define WHS_HUGE huge
#endif


/****************************************************************************
   Instructions for packing the following structure
*****************************************************************************/
#ifndef RC_INVOKED
   #pragma pack(1)
#endif

/****************************************************************************
   Instructions to resume the default structure packing.
*****************************************************************************/
#ifndef RC_INVOKED
   #pragma pack()
#endif


/******************************************************************************
                     Editor Function Prototype
   When calling WHS from a C program, leave the WHS_CPLUSPLUS symbol undefined.

   When calling WHS from a C++ program, define the WHS_CPLUSPLUS as following:

   #define WHS_CPLUSPLUS extern "C"
   #include "ter.h"
*******************************************************************************/
#ifndef WHS_CPLUSPLUS
   #if defined(__cplusplus)
      #define WHS_CPLUSPLUS extern "C"
   #else
      #define WHS_CPLUSPLUS
   #endif
#endif

WHS_CPLUSPLUS DWORD_PTR   WINAPI _export WhsNewSession();
WHS_CPLUSPLUS BOOL    WINAPI _export WhsEndSession(DWORD_PTR);
WHS_CPLUSPLUS BOOL    WINAPI _export WhsConvertFile(DWORD_PTR,LPBYTE,LPBYTE);
WHS_CPLUSPLUS HGLOBAL WINAPI _export WhsConvertBuffer(DWORD_PTR,LPBYTE,int,LPINT);
WHS_CPLUSPLUS BOOL    WINAPI _export WhsHandleToStr(LPBYTE,int,HANDLE);
WHS_CPLUSPLUS int     WINAPI _export WhsGetLastMessage(DWORD_PTR,LPBYTE,LPBYTE);
WHS_CPLUSPLUS BOOL    WINAPI _export WhsResetLastMessage(DWORD_PTR);
WHS_CPLUSPLUS DWORD   WINAPI _export WhsSetFlags(DWORD_PTR,BOOL,int);
WHS_CPLUSPLUS int     WINAPI _export WhsGetPictCount(DWORD_PTR);
WHS_CPLUSPLUS BOOL    WINAPI _export WhsGetPictName(DWORD_PTR,int,LPBYTE);
WHS_CPLUSPLUS BOOL    WINAPI _export WhsSetPaperSize(DWORD_PTR, int, int, int);
WHS_CPLUSPLUS BOOL    WINAPI _export WhsSetPaperOrient(DWORD_PTR, int);
WHS_CPLUSPLUS BOOL    WINAPI _export WhsSetPageMargin(DWORD_PTR, int, int, int, int);
WHS_CPLUSPLUS BOOL    WINAPI _export WhsSetDownloadDir(DWORD_PTR, LPBYTE);
WHS_CPLUSPLUS int     WINAPI _export WhsSetLicenseInfo(LPBYTE, LPBYTE, LPBYTE);
WHS_CPLUSPLUS int     WINAPI _export WhsSetLicenseInfoU(LPWORD,LPWORD,LPWORD);
WHS_CPLUSPLUS BOOL    WINAPI _export WhsSetInServer(BOOL);
WHS_CPLUSPLUS int     WINAPI _export WhsGetLicenseStatus();
WHS_CPLUSPLUS BOOL    WINAPI _export WhsSetHtmlDocTitle(DWORD_PTR, LPBYTE);


#endif
